@@ -1,7 +1,8 @@
 from uuid import uuid4
 
 from time import time
-from app.utils.network import local_ip
+
+from tracardi.service.network import local_ip
 from tracardi.service.singleton import Singleton
 from tracardi.domain.value_object.storage_info import StorageInfo
 from tracardi.domain.entity import Entity
@@ -34,7 +35,9 @@ class ApiInstance(metaclass=Singleton):
         self._start_time = time()
 
     def get_record(self) -> ApiInstanceRecord:
-        self.record.track_rps = self.record.track_requests / (time() - self._start_time)
+        passed_time = time() - self._start_time
+        self.record.track_rps = (self.record.track_requests / passed_time) if passed_time > 0 \
+            else self.record.track_requests/0.000001
         return self.record
 
     def reset(self):
