@@ -12,9 +12,13 @@ class PII(BaseModel):
     """
 
     name: Optional[Any] = None
-    surname: Optional[Any] = None
-    birthDate: Optional[Any] = None
+    last_name: Optional[Any] = None
+    birth_date: Optional[Any] = None
+    marital_status: Optional[str] = None
     email: Optional[Any] = None
     telephone: Optional[Any] = None
+    twitter: Optional[Any] = None
+    facebook: Optional[Any] = None
+    whatsapp: Optional[Any] = None
     other: Optional[dict] = {}
 
