@@ -1,5 +1,4 @@
-from typing import Optional
-
+from typing import Optional, Any
 from tracardi.domain.named_entity import NamedEntity
 from tracardi.domain.value_object.storage_info import StorageInfo
 
@@ -9,15 +8,15 @@ class Segment(NamedEntity):
     eventType: Optional[str] = None
     condition: str
     enabled: bool = True
+    machine_name: str = None
+
+    def __init__(self, **data: Any):
+        super().__init__(**data)
+        self.machine_name = self.get_id()
 
     def get_id(self) -> str:
         return self.name.replace(" ", "-").lower()
 
-    # Persistence
-
-    # def storage(self) -> StorageCrud:
-    #     return StorageCrud("segment", Segment, entity=self)
-
     @staticmethod
     def storage_info() -> StorageInfo:
         return StorageInfo(
