@@ -1,3 +1,5 @@
+from typing import Any
+
 from pydantic import BaseModel
 from tracardi.domain.enum.yes_no import YesNo
 
@@ -9,3 +11,9 @@ class Settings(BaseModel):
     @staticmethod
     def as_bool(state: YesNo):
         return state.value == state.yes
+
+
+class SystemSettings(BaseModel):
+    label: str
+    value: Any
+    desc: str
