@@ -1,13 +1,14 @@
 from datetime import datetime
 from typing import Optional, Any
-
 from pydantic import BaseModel
 
 
 class Time(BaseModel):
     insert: Optional[datetime]
+    lastVisit: Optional[datetime]
 
     def __init__(self, **data: Any):
-        data['insert'] = datetime.utcnow()
+        if 'insert' not in data:
+            data['insert'] = datetime.utcnow()
         super().__init__(**data)
 
