@@ -128,7 +128,7 @@ class DatetimeRangePayload(BaseModel):
     maxDate: Optional[DatePayload] = None
     where: Optional[str] = ""
     timeZone: Optional[str] = None
-    offset: Optional[int] = 0
+    start: Optional[int] = 0
     limit: Optional[int] = 20
     rand: Optional[float] = 0
 
@@ -140,9 +140,6 @@ class DatetimeRangePayload(BaseModel):
         if self._is_now(self.maxDate):
             self.maxDate = DatePayload(absolute=DatetimePayload.now())
 
-        print("_is_min_date_absolute", self._is_min_date_absolute())
-        print("_is_max_date_absolute", self._is_max_date_absolute())
-
         # Set Anchor date
         if self._is_min_date_absolute() and not self._is_max_date_absolute():
             self.maxDate.absolute = self.minDate.absolute
