@@ -1,3 +1,4 @@
+from typing import Optional
 from pydantic import BaseModel
 from tracardi.domain.value_object.save_result import SaveResult
 
@@ -5,4 +6,4 @@ from tracardi.domain.value_object.save_result import SaveResult
 class CollectResult(BaseModel):
     session: SaveResult
     events: SaveResult
-    profile: SaveResult
+    profile: Optional[SaveResult] = None
