@@ -1,26 +1,48 @@
 import asyncio
+import re
 from concurrent.futures import ThreadPoolExecutor
 
 from device_detector import DeviceDetector
+from pydantic import BaseModel, validator
 
 from tracardi_dot_notation.dot_accessor import DotAccessor
-from tracardi_plugin_sdk.domain.register import Plugin, Spec, MetaData
+from tracardi_plugin_sdk.domain.register import Plugin, Spec, MetaData, Form, FormGroup, FormField, FormComponent, \
+    Documentation, PortDoc
 from tracardi_plugin_sdk.domain.result import Result
 from tracardi_plugin_sdk.action_runner import ActionRunner
 
 
+class AgentConfiguration(BaseModel):
+    agent: str
+
+    @validator("agent")
+    def is_valid_dot_path(cls, value):
+        if len(value) < 1:
+            raise ValueError("Event type can not be empty.")
+
+        if value != value.strip():
+            raise ValueError(f"This field must not have space. Space is at the end or start of '{value}'")
+
+        return value
+
+
+def validate(config: dict) -> AgentConfiguration:
+    return AgentConfiguration(**config)
+
+
 class DetectClientAgentAction(ActionRunner):
 
     def __init__(self, **kwargs):
-        if 'userAgent' not in kwargs:
-            raise ValueError("Please define userAgent path with dot notation.")
+        self.config = validate(kwargs)
+        self.config.agent = self.config.agent.strip()
 
-        self.user_agent = kwargs['userAgent']
-
-    @staticmethod
-    def detect_device(ua):
-        detector = DeviceDetector(ua, skip_bot_detection=False)
-        return detector.parse()
+    def detect_device(self, ua):
+        try:
+            detector = DeviceDetector(ua, skip_bot_detection=False)
+            return detector.parse()
+        except Exception as e:
+            self.console.error(str(e))
+            return {}
 
     async def run(self, payload):
 
@@ -28,8 +50,8 @@ class DetectClientAgentAction(ActionRunner):
             if not isinstance(self.session.context, dict):
                 raise KeyError("No session context defined.")
 
-            dot = DotAccessor(self.profile, self.session, payload, self.event, self.flow)
-            ua = dot[self.user_agent]
+            dot = self._get_dot_accessor(payload)
+            ua = dot[self.config.agent]
 
             with ThreadPoolExecutor(max_workers=10) as pool:
                 loop = asyncio.get_event_loop()
@@ -101,7 +123,7 @@ class DetectClientAgentAction(ActionRunner):
                 }
             }
 
-        return Result(port="client-info", value=response)
+        return Result(port="payload", value=response)
 
 
 def register() -> Plugin:
@@ -112,25 +134,45 @@ def register() -> Plugin:
             module='tracardi.process_engine.action.v1.detect_client_agent_action',
             className='DetectClientAgentAction',
             inputs=["payload"],
-            outputs=["client-info"],
+            outputs=["payload"],
             init={
-                "userAgent": "session@context.browser.browser.userAgent"
+                "agent": "session@context.browser.browser.userAgent"
             },
+            form=Form(groups=[
+                FormGroup(
+                    name="Detect client type",
+                    fields=[
+                        FormField(
+                            id="agent",
+                            name="Path to user agent data",
+                            description="Type path to field that has user agent data. "
+                                        "E.g. session@context.browser.browser.userAgent",
+                            component=FormComponent(type="dotPath", props={"label": "Field path"})
+                        )
+                    ]
+                )
+            ]),
             manual="detect_client_agent_action",
             version='0.1.1',
             license="MIT",
             author="Risto Kowaczewski"
         ),
         metadata=MetaData(
-            name='Parse client agent',
-            desc='It will parse any user agent and detect the browser, operating system, device used (desktop, '
+            name='Get client agent',
+            desc='It will parse any user agent string and detect the browser, operating system, device used (desktop, '
                  'tablet, mobile, tv, cars, console, etc.), brand and model. It detects thousands '
-                 'of user agent strings, even from rare and obscure browsers and devices. It returns an object containing '
-                 'all the information',
-            type='flowNode',
-            width=200,
-            height=100,
+                 'of user agent strings, even from rare and obscure browsers and devices. It returns an '
+                 'object containing all the information',
             icon='browser',
-            group=["Traits"]
+            group=["Data processing"],
+            documentation=Documentation(
+                inputs={
+                    "payload": PortDoc(desc="This port takes any JSON-like object.")
+                },
+                outputs={
+                    "payload": PortDoc(desc="This port returns information about user's client, so browser, "
+                                            "device info, etc.")
+                }
+            )
         )
     )
