@@ -1,8 +1,9 @@
 import asyncio
+import traceback
 from asyncio import Task
 from collections import defaultdict
 from time import time
-from typing import Dict, List, Tuple
+from typing import Dict, List, Tuple, Optional
 from pydantic import ValidationError
 from tracardi.domain.event import Event
 
@@ -17,13 +18,14 @@ from ..domain.entity import Entity
 from ..domain.profile import Profile
 from ..domain.session import Session
 from ..domain.rule import Rule
+from ..exceptions.exception_service import get_traceback
 
 
 class RulesEngine:
 
     def __init__(self,
                  session: Session,
-                 profile: Profile,
+                 profile: Optional[Profile],
                  events_rules: List[Tuple[Task, Event]],
                  console_log=None
                  ):
@@ -33,13 +35,14 @@ class RulesEngine:
 
         self.console_log = console_log
         self.session = session
-        self.profile = profile
+        self.profile = profile  # Profile can be None if profile_less event
         self.events_rules = events_rules
 
-    async def invoke(self, load_flow_callable, source_id=None) -> Tuple[Dict[str, List[Dict[str, DebugInfo]]], list, list]:
+    async def invoke(self, load_flow_callable, ux: list, source_id=None) -> Tuple[Dict[str, List[Dict[str, DebugInfo]]], list, list, dict, Dict[str, list]]:
 
         flow_task_store = defaultdict(list)
         debug_info_by_event_type_and_rule_name = defaultdict(list)
+        invoked_rules = defaultdict(list)
 
         for rules_loading_task, event in self.events_rules:
 
@@ -48,6 +51,10 @@ class RulesEngine:
 
             for rule in rules:
 
+                # this is main roles loop
+                if 'name' in rule:
+                    invoked_rules[event.type].append(rule['name'])
+
                 try:
                     rule = Rule(**rule)
                 except ValidationError as e:
@@ -59,7 +66,11 @@ class RulesEngine:
                     continue
 
                 try:
+
+                    # Loads flow for given rule
+
                     flow = await load_flow_callable(rule.flow.id)
+
                 except Exception as e:
                     # This is empty DebugInfo without nodes
                     debug_info = DebugInfo(
@@ -80,37 +91,43 @@ class RulesEngine:
 
                 if source_id:
                     if source_id == event.source.id:
+
+                        # Create workflow and pass data
+
                         # todo FlowHistory is empty
                         workflow = WorkFlow(
                             FlowHistory(history=[]),
                             self.session,
-                            self.profile,
-                            event
+                            self.profile
                         )
-                        flow_task = asyncio.create_task(workflow.invoke(flow, debug=False))
+
+                        # Flows are run concurrently
+
+                        flow_task = asyncio.create_task(workflow.invoke(flow, event, ux, debug=False))
                         flow_task_store[event.type].append((rule.flow.id, event.id, rule.name, flow_task))
                 else:
                     # todo FlowHistory is empty
                     workflow = WorkFlow(
                         FlowHistory(history=[]),
                         self.session,
-                        self.profile,
-                        event
+                        self.profile
                     )
 
                     # Creating task can cause problems. It must be thoroughly tested as
                     # concurrently running flows on the same profile may override profile data.
                     # Preliminary tests showed no issues but on heavy load we do not know if
                     # the test is still valid and every thing is ok. Solution is to remove create_task.
-                    flow_task = asyncio.create_task(workflow.invoke(flow, debug=False))
+                    flow_task = asyncio.create_task(workflow.invoke(flow, event, ux, debug=False))
                     flow_task_store[event.type].append((rule.flow.id, event.id, rule.name, flow_task))
 
         # Run flows and report async
 
+        post_invoke_events = {}
         for event_type, tasks in flow_task_store.items():
             for flow_id, event_id, rule_name, task in tasks:
                 try:
-                    debug_info, log_list = await task  # type: DebugInfo, List[Log]
+                    debug_info, log_list, post_invoke_event = await task  # type: DebugInfo, List[Log], Event
+                    post_invoke_events[post_invoke_event.id] = post_invoke_event
 
                     # Store logs in one console log
                     for log in log_list:  # type: Log
@@ -121,13 +138,13 @@ class RulesEngine:
                             module=log.module,
                             class_name=log.class_name,
                             type=log.type,
-                            message=log.message
+                            message=log.message,
+                            traceback=log.traceback
                         )
                         self.console_log.append(console)
 
                 except Exception as e:
                     # todo log error
-
                     console = Console(
                         origin="workflow",
                         event_id=event_id,
@@ -135,7 +152,8 @@ class RulesEngine:
                         module='tracardi.process_engine.rules_engine',
                         class_name="RulesEngine",
                         type="error",
-                        message=str(e)
+                        message=repr(e),
+                        traceback=get_traceback(e)
                     )
                     self.console_log.append(console)
 
@@ -152,7 +170,11 @@ class RulesEngine:
 
         ran_event_types = list(flow_task_store.keys())
 
-        return debug_info_by_event_type_and_rule_name, ran_event_types, self.console_log
+        return debug_info_by_event_type_and_rule_name, \
+               ran_event_types, \
+               self.console_log, \
+               post_invoke_events, \
+               invoked_rules
 
     @staticmethod
     def _mark_profiles_as_merged(profiles, merge_with) -> List[Profile]:
