@@ -10,9 +10,11 @@ class Parser:
         import_paths = [
             os.path.join(_local_dir, 'grammar')
         ]
+        self.transformer = transformer
         self.base_parser = Lark(grammar,
                                 start=start,
-                                transformer=transformer,
+                                parser=parser,
+                                transformer=self.transformer,
                                 import_paths=import_paths)
 
     @staticmethod
@@ -22,3 +24,4 @@ class Parser:
 
     def parse(self, query):
         return self.base_parser.parse(query)
+
