@@ -2,8 +2,12 @@ import base64
 import json
 import gzip
 
+from pydantic import BaseModel
+
 
 def b64_encoder(data):
+    if isinstance(data, BaseModel):
+        data = data.dict()
     json_init = json.dumps(data, default=str)
     gziped = gzip.compress(bytes(json_init, 'utf-8'))
     b64 = base64.b64encode(gziped)
