@@ -1,67 +1,15 @@
 import logging
 from uuid import uuid4
 from elasticsearch import helpers, AsyncElasticsearch
-from elasticsearch._async.client.sql import SqlClient
-from elasticsearch._async.client.utils import SKIP_IN_PATH, query_params
 from elasticsearch.exceptions import NotFoundError
-
 from ssl import create_default_context
-
+from tracardi.config import elastic, ON_PREMISES, AWS_CLOUD
 from tracardi import config
 from tracardi.domain.value_object.bulk_insert_result import BulkInsertResult
 
 _singleton = None
-logger = logging.getLogger(__file__)
-logger.setLevel(logging.DEBUG)
-
-class AwsCompatibleSqlClient(SqlClient):
-
-    @query_params()
-    async def clear_cursor(self, body, params=None, headers=None):
-        """
-        Clears the SQL cursor
-
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/sql-pagination.html>`_
-
-        :arg body: Specify the cursor value in the `cursor` element to
-            clean the cursor.
-        """
-        if body in SKIP_IN_PATH:
-            raise ValueError("Empty value passed for a required argument 'body'.")
-
-        return await self.transport.perform_request(
-            "POST", "/_sql/close", params=params, headers=headers, body=body
-        )
-
-    @query_params("format")
-    async def query(self, body, params=None, headers=None):
-        """
-        Executes a SQL request
-
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/sql-rest-overview.html>`_
-
-        :arg body: Use the `query` element to start a query. Use the
-            `cursor` element to continue a query.
-        :arg format: a short version of the Accept header, e.g. json,
-            yaml
-        """
-        if body in SKIP_IN_PATH:
-            raise ValueError("Empty value passed for a required argument 'body'.")
-
-        return await self.transport.perform_request(
-            "POST", "/_sql", params=params, headers=headers, body=body
-        )
-
-    @query_params()
-    async def translate(self, body, params=None, headers=None):
-
-        if body in SKIP_IN_PATH:
-            raise ValueError("Empty value passed for a required argument 'body'.")
-
-        return await self.transport.perform_request(
-            config.elastic.sql_translate_method, config.elastic.sql_translate_url, params=params, headers=headers,
-            body=body
-        )
+logger = logging.getLogger(__name__)
+logger.setLevel(elastic.logging_level)
 
 
 class ElasticClient:
@@ -69,15 +17,14 @@ class ElasticClient:
     def __init__(self, **kwargs):
         self._cache = {}
         self._client = AsyncElasticsearch(**kwargs)
-        self._client.sql = AwsCompatibleSqlClient(self._client)
-
-    async def translate(self, sql):
-        return await self._client.sql.translate(body=sql)
+        # todo remove if not use of sql translate
+        # self._client.sql = AwsCompatibleSqlClient(self._client)
 
     async def close(self):
         await self._client.close()
 
     async def get(self, index, id):
+        logger.debug(f"GET DOCUMENT: {index}, {id}")
         return await self._client.get(index=index, doc_type='_doc', id=id)
 
     # todo error handling move to service
@@ -105,7 +52,7 @@ class ElasticClient:
         return await self._client.search(index=index, body=query)
 
     async def scan(self, index, query):
-
+        logger.debug(f"SCAN INDEX: {index}, {query}")
         _generator = helpers.async_scan(
             self._client,
             query=query,
@@ -117,6 +64,8 @@ class ElasticClient:
 
     async def insert(self, index, records) -> BulkInsertResult:
 
+        logger.debug(f"INSERT: {index}, {records}")
+
         if not isinstance(records, list):
             raise ValueError("Insert expects payload to be list.")
 
@@ -151,23 +100,36 @@ class ElasticClient:
         return await self._client.update(index, body=record, id=id)
 
     async def remove_index(self, index):
+        logger.debug(f"REMOVE INDEX: {index}")
         return await self._client.indices.delete(index=index)
 
     async def create_index(self, index, mappings):
+        logger.debug(f"CREATE INDEX: {index}")
         return await self._client.indices.create(index=index, ignore=400, body=mappings)
 
+    async def put_index_template(self, template_name, mappings):
+        logger.debug(f"PUT INDEX TEMPLATE: {template_name}")
+        return await self._client.indices.put_index_template(name=template_name, ignore=400, body=mappings)
+
     async def exists_index(self, index):
+        logger.debug(f"EXISTS INDEX: {index}")
         return await self._client.indices.exists(index=index)
 
     async def list_indices(self):
         return await self._client.indices.get("*")
 
     async def refresh(self, index, params=None, headers=None):
+        logger.debug(f"REFRESH INDEX: {index}")
         return await self._client.indices.refresh(index=index, params=params, headers=headers)
 
     async def flush(self, index, params=None, headers=None):
+        logger.debug(f"FLUSH INDEX: {index}")
         return await self._client.indices.flush(index=index, params=params, headers=headers)
 
+    async def update_by_query(self, index, query):
+        logger.debug(f"UPDATED BY QUERY on INDEX: {index}")
+        return await self._client.update_by_query(index=index, body=query)
+
     @staticmethod
     def _get_elastic_config():
 
@@ -202,6 +164,9 @@ class ElasticClient:
         if config.elastic.http_compress:
             kwargs['http_compress'] = config.elastic.http_compress
 
+        if config.elastic.verify_certs is not None:
+            kwargs['verify_certs'] = config.elastic.verify_certs
+
         return kwargs
 
     @staticmethod
@@ -211,7 +176,10 @@ class ElasticClient:
 
         def get_elastic_client():
             kwargs = ElasticClient._get_elastic_config()
-            return ElasticClient(**kwargs)
+            if config.elastic.hosting == ON_PREMISES:
+                return ElasticClient(**kwargs)
+            elif config.elastic.hosting == AWS_CLOUD:
+                raise ConnectionError("Not implemented")
 
         if _singleton is None:
             _singleton = get_elastic_client()
