@@ -1,6 +1,6 @@
 import elasticsearch
-from typing import Union
-from tracardi.service.storage.elastic_storage import ElasticStorage
+from typing import Union, List, Optional
+from tracardi.service.storage.elastic_storage import ElasticStorage, ElasticFiledSort
 from tracardi.service.storage.persistence_service import PersistenceService
 from tracardi.domain.entity import Entity
 from pydantic import BaseModel
@@ -44,11 +44,23 @@ class EntityStorageCrud(BaseStorageCrud):
         service = self._get_storage_service()
         return await service.load_by(field, value, limit)
 
+    async def load_by_query_string(self, query_string: str, limit: int = 100) -> StorageResult:
+        service = self._get_storage_service()
+        return await service.load_by_query_string(query_string, limit)
+
+    async def match_by(self, field: str, value: str, limit: int = 100) -> StorageResult:
+        service = self._get_storage_service()
+        return await service.match_by(field, value, limit)
+
+    async def load_by_values(self, key_value_pairs: List[tuple], sort_by: Optional[List[ElasticFiledSort]] = None, limit: int = 100):
+        service = self._get_storage_service()
+        return await service.load_by_values(key_value_pairs, sort_by, limit=limit)
+
     async def delete_by(self, field, value) -> dict:
         service = self._get_storage_service()
         return await service.delete_by(field, value)
 
-    async def save(self, row=None):
+    async def save(self, row=None) -> BulkInsertResult:
         if row is None:
             row = {}
         row['id'] = self.entity.id
@@ -83,38 +95,41 @@ class CollectionCrud:
         self.index = index
         self.storage = storage_manager(self.index)
 
-    async def save(self, replace_id: bool = True) -> BulkInsertResult:
-        try:
-            if not isinstance(self.payload, list):
-                raise TracardiException("CollectionCrud data payload must be list.")
-            data = [p.dict() for p in self.payload if isinstance(p, BaseModel)]
-            return await self.storage.upsert(data, replace_id)
+    async def save(self, replace_id: bool = True, exclude=None) -> BulkInsertResult:
+        if not isinstance(self.payload, list):
+            raise TracardiException("CollectionCrud data payload must be list.")
+        data = [p.dict(exclude=exclude) for p in self.payload if isinstance(p, BaseModel)]
+        return await self.storage.upsert(data, replace_id)
 
-        except elasticsearch.exceptions.ElasticsearchException as e:
-            raise StorageException(str(e))
-
-    async def load(self) -> StorageResult:
+    async def load(self, start: int = 0, limit: int = 100) -> StorageResult:
         try:
 
-            return await self.storage.load_all()
+            return await self.storage.load_all(start, limit)
 
         except elasticsearch.exceptions.ElasticsearchException as e:
+            if len(e.args):
+                message, details = e.args
+                raise StorageException(str(e), message=message, details=details)
             raise StorageException(str(e))
 
-    async def uniq_field_value(self, field) -> AggResult:
+    async def uniq_field_value(self, field, search=None, limit=500) -> AggResult:
         try:
             query = {
                 "size": "0",
                 "aggs": {
                     "uniq": {
                         "terms": {
-                            "field": field
+                            "field": field,
+                            "size": limit
                         }
                     }
                 }
             }
             return AggResult('uniq', await self.storage.query(query), return_counts=False)
         except elasticsearch.exceptions.ElasticsearchException as e:
+            if len(e.args):
+                message, details = e.args
+                raise StorageException(str(e), message=message, details=details)
             raise StorageException(str(e))
 
 
